# Class: Cluster&#95;host

Cluster member metadata

## Fields for class: Cluster&#95;host

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`allowed_operations`|`cluster_host_operation set`|_RO/runtime_   |list of the operations allowed in this state. This list is advisory only and the server state may have changed by the time this field is read by a client.|
|`cluster`           |`Cluster ref`       |_RO/constructor_|Reference to the Cluster object         |
|`current_operations`|`(string -> cluster_host_operation) map`|_RO/runtime_   |links each of the running tasks using this object &#40;by reference&#41; to a current&#95;operation enum which describes the nature of the task.|
|`enabled`           |`bool`              |_RO/runtime_   |Whether the cluster host believes that clustering should be enabled on this host. This field can be altered by calling the enable/disable message on a cluster host. Only enabled members run the underlying cluster stack. Disabled members are still considered a member of the cluster &#40;see joined&#41;, and can be re&#45;enabled by the user.|
|`host`              |`host ref`          |_RO/constructor_|Reference to the Host object            |
|`joined`            |`bool`              |_RO/runtime_   |Whether the cluster host has joined the cluster. Contrary to enabled, a host that is not joined is not considered a member of the cluster, and hence enable and disable operations cannot be performed on this host.|
|`last_update_live`  |`datetime`          |_RO/runtime_   |Time when the live field was last updated based on information from the cluster stack|
|`live`              |`bool`              |_RO/runtime_   |Whether the underlying cluster stack thinks we are live. This field is set automatically based on updates from the cluster stack and cannot be altered by the user.|
|`other_config`      |`(string -> string) map`|_RO/constructor_|Additional configuration                |
|`PIF`               |`PIF ref`           |_RO/constructor_|Reference to the PIF object             |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |

## RPCs associated with class: Cluster&#95;host

### RPC name: create

_Overview:_

Add a new host to an existing cluster.

_Signature:_

```
Cluster_host ref create (session ref session_ref, Cluster ref cluster, host ref host, PIF ref pif)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster ref`                 |`cluster`                     |Cluster to join                         |
|`host ref`                    |`host`                        |new cluster member                      |
|`PIF ref`                     |`pif`                         |Network interface to use for communication|

_Minimum Role:_ pool-operator

_Return Type:_ `Cluster_host ref`

the newly created cluster&#95;host object

_Possible Error Codes:_ `PIF_NOT_ATTACHED_TO_HOST`, `NO_CLUSTER_HOSTS_REACHABLE`

### RPC name: destroy

_Overview:_

Remove the host from an existing cluster. This operation is allowed even if a cluster host is not enabled.

_Signature:_

```
void destroy (session ref session_ref, Cluster_host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster_host ref`            |`self`                        |the cluster&#95;host to remove from the cluster|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `CLUSTER_STACK_IN_USE`, `CLUSTERING_DISABLED`, `CLUSTER_HOST_IS_LAST`

### RPC name: disable

_Overview:_

Disable cluster membership for an enabled cluster host.

_Signature:_

```
void disable (session ref session_ref, Cluster_host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster_host ref`            |`self`                        |the cluster&#95;host to disable         |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `CLUSTER_STACK_IN_USE`

### RPC name: enable

_Overview:_

Enable cluster membership for a disabled cluster host.

_Signature:_

```
void enable (session ref session_ref, Cluster_host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster_host ref`            |`self`                        |the cluster&#95;host to enable          |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `PIF_ALLOWS_UNPLUG`, `REQUIRED_PIF_IS_UNPLUGGED`

### RPC name: force&#95;destroy

_Overview:_

Remove a host from an existing cluster forcefully.

_Signature:_

```
void force_destroy (session ref session_ref, Cluster_host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster_host ref`            |`self`                        |the cluster&#95;host to remove from the cluster|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `CLUSTER_STACK_IN_USE`

### RPC name: get&#95;all

_Overview:_

Return a list of all the Cluster&#95;hosts known to the system.

_Signature:_

```
Cluster_host ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `Cluster_host ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of Cluster&#95;host references to Cluster&#95;host records for all Cluster&#95;hosts known to the system.

_Signature:_

```
(Cluster_host ref -> Cluster_host record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(Cluster_host ref -> Cluster_host record) map`

records of all objects

### RPC name: get&#95;allowed&#95;operations

_Overview:_

Get the allowed&#95;operations field of the given Cluster&#95;host.

_Signature:_

```
cluster_host_operation set get_allowed_operations (session ref session_ref, Cluster_host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster_host ref`            |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `cluster_host_operation set`

value of the field

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the Cluster&#95;host instance with the specified UUID.

_Signature:_

```
Cluster_host ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `Cluster_host ref`

reference to the object

### RPC name: get&#95;cluster

_Overview:_

Get the cluster field of the given Cluster&#95;host.

_Signature:_

```
Cluster ref get_cluster (session ref session_ref, Cluster_host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster_host ref`            |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Cluster ref`

value of the field

### RPC name: get&#95;current&#95;operations

_Overview:_

Get the current&#95;operations field of the given Cluster&#95;host.

_Signature:_

```
(string -> cluster_host_operation) map get_current_operations (session ref session_ref, Cluster_host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster_host ref`            |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> cluster_host_operation) map`

value of the field

### RPC name: get&#95;enabled

_Overview:_

Get the enabled field of the given Cluster&#95;host.

_Signature:_

```
bool get_enabled (session ref session_ref, Cluster_host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster_host ref`            |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;host

_Overview:_

Get the host field of the given Cluster&#95;host.

_Signature:_

```
host ref get_host (session ref session_ref, Cluster_host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster_host ref`            |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

### RPC name: get&#95;joined

_Overview:_

Get the joined field of the given Cluster&#95;host.

_Signature:_

```
bool get_joined (session ref session_ref, Cluster_host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster_host ref`            |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;last&#95;update&#95;live

_Overview:_

Get the last&#95;update&#95;live field of the given Cluster&#95;host.

_Signature:_

```
datetime get_last_update_live (session ref session_ref, Cluster_host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster_host ref`            |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

### RPC name: get&#95;live

_Overview:_

Get the live field of the given Cluster&#95;host.

_Signature:_

```
bool get_live (session ref session_ref, Cluster_host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster_host ref`            |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given Cluster&#95;host.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, Cluster_host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster_host ref`            |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;PIF

_Overview:_

Get the PIF field of the given Cluster&#95;host.

_Signature:_

```
PIF ref get_PIF (session ref session_ref, Cluster_host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster_host ref`            |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF ref`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given Cluster&#95;host.

_Signature:_

```
Cluster_host record get_record (session ref session_ref, Cluster_host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster_host ref`            |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Cluster_host record`

all fields from the object

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given Cluster&#95;host.

_Signature:_

```
string get_uuid (session ref session_ref, Cluster_host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster_host ref`            |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field
