# Class: VTPM

A virtual TPM device

## Fields for class: VTPM

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`allowed_operations`|`vtpm_operations set`|_RO/runtime_   |list of the operations allowed in this state. This list is advisory only and the server state may have changed by the time this field is read by a client.|
|`backend`           |`VM ref`            |_RO/runtime_   |The domain where the backend is located &#40;unused&#41;|
|`current_operations`|`(string -> vtpm_operations) map`|_RO/runtime_   |links each of the running tasks using this object &#40;by reference&#41; to a current&#95;operation enum which describes the nature of the task.|
|`is_protected`      |`bool`              |_RO/runtime_   |Whether the contents of the VTPM are secured according to the TPM spec|
|`is_unique`         |`bool`              |_RO/constructor_|Whether the contents are never copied, satisfying the TPM spec|
|`persistence_backend`|`persistence_backend`|_RO/runtime_   |The backend where the vTPM is persisted |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`VM`                |`VM ref`            |_RO/constructor_|The virtual machine the TPM is attached to|

## RPCs associated with class: VTPM

### RPC name: create

_Overview:_

Create a new VTPM instance, and return its handle.

_Signature:_

```
VTPM ref create (session ref session_ref, VM ref vM, bool is_unique)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM ref`                      |`vM`                          |The VM reference the VTPM will be attached to|
|`bool`                        |`is_unique`                   |Whether the VTPM must be unique         |

_Minimum Role:_ vm-admin

_Return Type:_ `VTPM ref`

The reference of the newly created VTPM

### RPC name: destroy

_Overview:_

Destroy the specified VTPM instance, along with its state.

_Signature:_

```
void destroy (session ref session_ref, VTPM ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VTPM ref`                    |`self`                        |The reference to the VTPM object        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the VTPMs known to the system.

_Signature:_

```
VTPM ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `VTPM ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of VTPM references to VTPM records for all VTPMs known to the system.

_Signature:_

```
(VTPM ref -> VTPM record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(VTPM ref -> VTPM record) map`

records of all objects

### RPC name: get&#95;allowed&#95;operations

_Overview:_

Get the allowed&#95;operations field of the given VTPM.

_Signature:_

```
vtpm_operations set get_allowed_operations (session ref session_ref, VTPM ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VTPM ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vtpm_operations set`

value of the field

### RPC name: get&#95;backend

_Overview:_

Get the backend field of the given VTPM.

_Signature:_

```
VM ref get_backend (session ref session_ref, VTPM ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VTPM ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref`

value of the field

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the VTPM instance with the specified UUID.

_Signature:_

```
VTPM ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VTPM ref`

reference to the object

### RPC name: get&#95;current&#95;operations

_Overview:_

Get the current&#95;operations field of the given VTPM.

_Signature:_

```
(string -> vtpm_operations) map get_current_operations (session ref session_ref, VTPM ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VTPM ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> vtpm_operations) map`

value of the field

### RPC name: get&#95;is&#95;protected

_Overview:_

Get the is&#95;protected field of the given VTPM.

_Signature:_

```
bool get_is_protected (session ref session_ref, VTPM ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VTPM ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;is&#95;unique

_Overview:_

Get the is&#95;unique field of the given VTPM.

_Signature:_

```
bool get_is_unique (session ref session_ref, VTPM ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VTPM ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;persistence&#95;backend

_Overview:_

Get the persistence&#95;backend field of the given VTPM.

_Signature:_

```
persistence_backend get_persistence_backend (session ref session_ref, VTPM ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VTPM ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `persistence_backend`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given VTPM.

_Signature:_

```
VTPM record get_record (session ref session_ref, VTPM ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VTPM ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VTPM record`

all fields from the object

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given VTPM.

_Signature:_

```
string get_uuid (session ref session_ref, VTPM ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VTPM ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;VM

_Overview:_

Get the VM field of the given VTPM.

_Signature:_

```
VM ref get_VM (session ref session_ref, VTPM ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VTPM ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref`

value of the field
